# Python-Economy
  Require to have Python 3.7 \
  This python package is just to make save files easier.

  To install

    # Windows
    pip install pythoneconomy

  Example of how to start using it

    from economy import economy
  
  To create a folder with a file inside

    from economy import economy
    economy.bal.start(foldername, filename,   {"Variable": 0})

  If you have any issues: \
  https://github.com/ErrorThree/Python-Economy/issues

  API Documentation: \
  Coming Soon
